@@ -132,8 +132,7 @@ setMethod("getGaps", "GRanges", function(obj, group.name = NULL, facets = NULL){
         return(GRanges())
     if(!length(facets))
         facets <- as.formula(~seqnames)
-    allvars <- all.vars(as.formula(facets))
-    allvars.extra <- allvars[!allvars %in% c(".", "seqnames")]
+    allvars.extra <- colnames(mcols(obj))
     if(!is.null(group.name)){
         if(!group.name %in% colnames(values(obj)))
             stop(group.name, " is not in obj")
@@ -300,7 +299,7 @@ fetch <- function(obj, which, ..., gene.id,
                   ratio = 0.0025,
                   resize.extra = 10,
                   include.level = TRUE,
-                  use.name = TRUE,
+                  use.names = TRUE,
                   columns = c("tx_id", "tx_name","gene_id"),
                   type = c("all", "single", "exons.reduce", "exons.all",
                       "exons.geneid",  "gapped.pair", "raw", "all")){
@@ -310,14 +309,14 @@ fetch <- function(obj, which, ..., gene.id,
 
     ## type <- match.arg(type)
     if(length(type) >1){
-        if(is(obj,"TranscriptDb"))
+        if(is(obj,"TxDb"))
             type <- "all"
         if(is(obj,"BamFile"))
             type <- "gapped.pair"
     }
-    if(is(obj, "TranscriptDb")){
+    if(is(obj, "TxDb")){
         if(!(type %in% .txdb.type))
-            stop("type for TranscriptDb must be ", .txdb.type)
+            stop("type for TxDb must be ", .txdb.type)
         if(is.list(which)){
             message("Parsing exons based on which(list) arguments")
             temp <- exons(obj, vals = which, columns = columns)
@@ -455,7 +454,7 @@ fetch <- function(obj, which, ..., gene.id,
         if(!length(obj))
             stop("No entry in the GappedAlignments data")
         if(is.null(names(obj)))
-            stop("Missing qname, please make use.name = TRUE, when reading GappedAlignments")
+            stop("Missing qname, please make use.names = TRUE, when reading GappedAlignments")
         grg <- grglist(obj)
         grg.u <- stack(grg, ".grl.name")
         message("extracting information...")
@@ -466,13 +465,12 @@ fetch <- function(obj, which, ..., gene.id,
     }
     if(is(obj, "BamFile")){
         if(!(type %in% .bamfile.type))
-            stop("type for TranscriptDb must be ", .bamfile.type)
+            stop("type for TxDb must be ", .bamfile.type)
         ## require(Rsamtools)
         if(type == "gapped.pair"){
             message("Read GappedAlignments from BamFile...")
-            ga <- readGAlignmentsFromBam(obj,
-                                         param = ScanBamParam(which = which),
-                                         use.names = use.name, ...)
+            ga <- readGAlignments(obj, param = ScanBamParam(which = which),
+                                       use.names = use.names, ...)
             res <- fetch(ga)
         }
 
@@ -486,9 +484,8 @@ fetch <- function(obj, which, ..., gene.id,
             res.mb <- scanBamGRanges(obj, which,
                                      flag = scanBamFlag(isFirstMateRead = TRUE))
             message("Read GappedAlignments from BamFile...")
-            ga <- readGAlignmentsFromBam(obj,
-                                         param = ScanBamParam(which = which),
-                                         use.names = use.name, ...)
+            ga <- readGAlignments(obj, param = ScanBamParam(which = which),
+                                       use.names = use.names, ...)
             res.gp <- fetch(ga)
             message("Combine...")
             nms <- values(res.mb)$qname
